        function getT(rr,cc){
       if(rr==3 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260507 a 12</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==3 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260507 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>42</strong> miembros: 25 <strong>control</strong><br>0,3,5,6,8,9,10,11,13,16,19,21,23,24,25,27,29,30,32,33,37,39,42,45,46';}
       if(rr==3 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260507 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>18</strong> miembros: 18 <br>4,7,12,17,18,20,22,31,34,35,36,38,40,41,43,47,48,49';}
       if(rr==3 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260507 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>50</strong> miembros: 8 <br>1,2,14,15,26,28,44,50';}
       if(rr==17 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260507 a 12</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==17 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260507 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>42</strong> miembros: 25 <strong>control</strong><br>0,3,5,6,8,9,10,11,13,16,19,21,23,24,25,27,29,30,32,33,37,39,42,45,46';}
       if(rr==17 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260507 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>18</strong> miembros: 18 <br>4,7,12,17,18,20,22,31,34,35,36,38,40,41,43,47,48,49';}
       if(rr==17 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260507 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>50</strong> miembros: 8 <br>1,2,14,15,26,28,44,50';}
       if(rr==19 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260507 a 12</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==19 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260507 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>42</strong> miembros: 25 <strong>control</strong><br>0,3,5,6,8,9,10,11,13,16,19,21,23,24,25,27,29,30,32,33,37,39,42,45,46';}
       if(rr==19 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260507 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>18</strong> miembros: 18 <br>4,7,12,17,18,20,22,31,34,35,36,38,40,41,43,47,48,49';}
       if(rr==19 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260507 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>50</strong> miembros: 8 <br>1,2,14,15,26,28,44,50';}
       if(rr==20 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260507 a 12</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==20 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260507 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>42</strong> miembros: 25 <strong>control</strong><br>0,3,5,6,8,9,10,11,13,16,19,21,23,24,25,27,29,30,32,33,37,39,42,45,46';}
       if(rr==20 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260507 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>18</strong> miembros: 18 <br>4,7,12,17,18,20,22,31,34,35,36,38,40,41,43,47,48,49';}
       if(rr==20 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260507 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>50</strong> miembros: 8 <br>1,2,14,15,26,28,44,50';}
       if(rr==21 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260507 a 12</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==21 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260507 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>42</strong> miembros: 25 <strong>control</strong><br>0,3,5,6,8,9,10,11,13,16,19,21,23,24,25,27,29,30,32,33,37,39,42,45,46';}
       if(rr==21 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260507 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>18</strong> miembros: 18 <br>4,7,12,17,18,20,22,31,34,35,36,38,40,41,43,47,48,49';}
       if(rr==21 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260507 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>50</strong> miembros: 8 <br>1,2,14,15,26,28,44,50';}
       if(rr==22 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260507 a 12</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==22 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260507 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>42</strong> miembros: 25 <strong>control</strong><br>0,3,5,6,8,9,10,11,13,16,19,21,23,24,25,27,29,30,32,33,37,39,42,45,46';}
       if(rr==22 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260507 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>18</strong> miembros: 18 <br>4,7,12,17,18,20,22,31,34,35,36,38,40,41,43,47,48,49';}
       if(rr==22 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260507 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>50</strong> miembros: 8 <br>1,2,14,15,26,28,44,50';}
}
